#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 text-printer
version:              0.5.0.2
visibility:           public
id:                   text-printer-0.5.0.2-8nKqhiYFKtFFJ2dBgoLh7Y
key:                  text-printer-0.5.0.2-8nKqhiYFKtFFJ2dBgoLh7Y
license:              BSD-3-Clause
copyright:            2013 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer:           Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
author:               Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability:            experimental
homepage:             https://github.com/mvv/text-printer
synopsis:             Abstract interface for text builders/printers.
description:
    This package provides an interface for injecting text into monoids such as
    builders and printers.

category:             Text
abi:                  c8dccdd0aa90767c2e2030d5138adc1f
exposed:              True
exposed-modules:
    Text.Printer Text.Printer.Fractional Text.Printer.Integral

import-dirs:          /usr/lib/ghc-9.6.6/site-local/text-printer-0.5.0.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/text-printer-0.5.0.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/text-printer-0.5.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-text-printer
hs-libraries:         HStext-printer-0.5.0.2-8nKqhiYFKtFFJ2dBgoLh7Y
depends:
    base-4.18.2.1 bytestring-0.11.5.3 pretty-1.1.3.6 text-2.0.2
    text-latin1-0.3.1-LhZCkFDbxHcDI62Db6BTx

haddock-interfaces:
    /usr/share/doc/haskell-text-printer/html/text-printer.haddock

haddock-html:         /usr/share/doc/haskell-text-printer/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

